@@ -38,6 +38,8 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, ConfirmTask):
             return obj.__dict__
+        elif isinstance(obj, ProgramState):
+            return obj.__dict__
         else:
             return json.JSONEncoder.default(self, obj)
 
@@ -80,6 +82,8 @@ class JsonDecoder(json.JSONDecoder):
                 return ConfirmNeeded(**obj)
             if '_type' in obj and obj['_type'] == 'confirm_task':
                 return ConfirmTask(**obj)
+            if '_type' in obj and obj['_type'] == 'program_state':
+                return ProgramState(**obj)
         return obj
 
 
