@@ -40,6 +40,15 @@ class Pose:
     def __repr__(self):
         return f"Pose<name={self.name}, position={self.position}, orientation={self.rotation}>"
 
+    def to_dict(self) -> dict:
+        return {'x': self.position.x, 'y': self.position.y, 'z': self.position.z,
+                'rx': self.rotation.x, 'ry': self.rotation.y, 'rz': self.rotation.z}
+
+    @staticmethod
+    def from_dict(pose: dict) -> 'Pose':
+        return Pose(Vector3(pose.get('x', 0.0), pose.get('y', 0.0), pose.get('z', 0.0)),
+                    Vector3(pose.get('rx', 0.0), pose.get('ry', 0.0), pose.get('rz', 0.0)), name=pose.get('name', ''))
+
 
 class Poses:
 
